@@ -47,9 +47,24 @@
     !any(is.na(nx))
 }
 
+# return TRUE if obj@misc$sigma is not NA
+.chk.predict = function(obj) {
+    sig = obj@misc$sigma
+    ok = (is.null(sig) || (!is.null(sig) && !is.na(sig)))
+    if(!ok)
+        warning("Prediction intervals are not available for this object", call. = FALSE)
+    ok
+}
+
+
 
 ## Alternative to all.vars, but keeps vars like foo$x and foo[[1]] as-is
 ##   Passes ... to all.vars
+#' @rdname extending-emmeans
+#' @order 41
+#' @param expr,retain Arguments for \code{.all.vars}, which is an alternative to \code{\link{all.vars}}
+#'   that has special provisions for retaining the special characters in \code{retain},
+#'   thus allowing model specifications like \code{y ~ data$trt * df[["dose"]]}
 #' @export
 .all.vars = function(expr, retain = c("\\$", "\\[\\[", "\\]\\]", "'", '"'), ...) {
     if (is.null(expr) || length(expr) == 0)
@@ -122,7 +137,13 @@
 ### Not-so-damn-smart replacement of diag() that will 
 ### not be so quick to assume I want an identity matrix
 ### returns matrix(x) when x is a scalar
+#' @rdname extending-emmeans
+#' @order 42
+#' @param x,nrow,ncol Arguments for \code{.diag}, which is an alternative to 
+#'   \code{\link{diag}} that lacks its idiosyncrasy of returning an
+#'   identity matrix when \code{x} is of length 1.
 #' @export
+#' 
 .diag = function(x, nrow, ncol) {
     if(is.matrix(x))
         diag(x)
@@ -156,6 +177,11 @@
 }
 
 # calculate the offset for the given grid
+#' @rdname extending-emmeans
+#' @order 35
+#' @param terms A \code{terms} component
+#' @return \code{.get.offset} returns the values, based on \code{grid}, of 
+#' any \code{offset} component in \code{terms}
 #' @export
 .get.offset = function(terms, grid) {
     off.idx = attr(terms, "offset")
@@ -167,6 +193,10 @@
 }
 
 # combine variables in several `terms` objects
+#' @rdname extending-emmeans
+#' @order 31
+#' @return \code{combine.terms} returns a \code{terms} object resulting
+#'   from combining all the terms or formulas in \code{...}.
 #' @export
 .combine.terms = function(...) {
     trms = list(...)
@@ -245,13 +275,13 @@
 }
 
 # return updated object with option list AND dot list
-# optionally may exclude any opts in 'exclude'
-.update.options = function(object, options, ..., exclude) {
+# optionally may exclude any opts in 'exclude.opts'
+.update.options = function(object, options, ..., exclude.opts) {
     if (!is.list(options))
         options = as.list(options)
     dot.opts = .match.dots.list(.valid.misc, ...)
-    if (!missing(exclude))
-        for (nm in exclude)
+    if (!missing(exclude.opts))
+        for (nm in exclude.opts)
             dot.opts[[nm]] = NULL
     # entries in both lists are overridden by those in ...
     for (nm in names(dot.opts))
@@ -393,6 +423,14 @@ model.frame = function(formula, data, ...) {
 # This is sufficient in lieu of the whole model matrix
 # Ideally, X is already a qr object in which case weights is assumed already incorporated
 # assign should be right if input is generated by model.matrix() or is $qr slot of lm
+#' @rdname extending-emmeans
+#' @order 33
+#' @param X,weights,assign Arguments for \code{.cmpMM}, which compacts a model
+#'   matrix \code{X} into a much smaller matrix that has the same row space.
+#'   Specifically, it returns the R portion of its QR decomposition. If \code{X}
+#'   is already of class \code{qr}, it is used directly. \code{weights} should be
+#'   the weights used in the model fit, and \code{assign} is used for unravelling
+#'   any pivoting done by \code{\link{qr}}.
 #' @export
 .cmpMM = function(X, weights = rep(1, nrow(X)), assign = attr(X$qr, "assign")) {
     if (!get_emm_option("enable.submodel"))
