@@ -127,14 +127,13 @@ emmeans.list = function(object, specs, ...) {
 #'   the result, it is subsetted or cyclically recycled.
 #' @param ... When \code{object} is not already a \code{"emmGrid"}
 #'   object, these arguments are passed to \code{\link{ref_grid}}. Common
-#'   examples are \code{at}, \code{cov.reduce}, \code{data}, code{type}, 
+#'   examples are \code{at}, \code{cov.reduce}, \code{data}, \code{type}, 
 #'   \code{regrid}, \code{df}, \code{nesting}, and \code{vcov.}.
 #'   Model-type-specific options (see
 #'   \href{../doc/models.html}{\code{vignette("models", "emmeans")}}), commonly
 #'   \code{mode}, may be used here as well. In addition, if the model formula
 #'   contains references to variables that are not predictors, you must provide
 #'   a \code{params} argument with a list of their names.
-#'   
 #'   These arguments may also be used in lieu of \code{options}. See the 
 #'   \sQuote{Options} section below.
 #' @param tran Placeholder to prevent it from being included in \code{...}.
@@ -456,7 +455,7 @@ emmeans = function(object, specs, by = NULL,
         result = if (missing(contr))
             .update.options(result, options, ...)
         else
-            .update.options(result, options, ..., exclude = "adjust")
+            .update.options(result, options, ..., exclude.opts = "adjust")
     }
     
     else {  # handle a nested structure
